<?php
/**
 * Plugin Name: LatePoint Addon - Coupons
 * Plugin URI:  https://latepoint.com/
 * Description: LatePoint addon for coupons
 * Version:     1.0.6
 * Author:      LatePoint
 * Author URI:  https://latepoint.com/
 * Text Domain: latepoint-coupons
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

// If no LatePoint class exists - exit, because LatePoint plugin is required for this addon

if ( ! class_exists( 'LatePointAddonCoupons' ) ) :

/**
 * Main Addon Class.
 *
 */

class LatePointAddonCoupons {

  /**
   * Addon version.
   *
   */
  public $version = '1.0.6';
  public $db_version = '1.0.0';
  public $addon_name = 'latepoint-coupons';




  /**
   * LatePoint Constructor.
   */
  public function __construct() {
    $this->define_constants();
    $this->init_hooks();
  }

  /**
   * Define LatePoint Constants.
   */
  public function define_constants() {
    $upload_dir = wp_upload_dir();

    global $wpdb;
    $this->define( 'LATEPOINT_TABLE_COUPONS', $wpdb->prefix . 'latepoint_coupons');

    $this->define( 'LATEPOINT_COUPON_STATUS_ACTIVE', 'active' );
    $this->define( 'LATEPOINT_COUPON_STATUS_DISABLED', 'disabled' );
  }


  public static function public_stylesheets() {
    return plugin_dir_url( __FILE__ ) . 'public/stylesheets/';
  }

  /**
   * Define constant if not already set.
   *
   */
  public function define( $name, $value ) {
    if ( ! defined( $name ) ) {
      define( $name, $value );
    }
  }

  /**
   * Include required core files used in admin and on the frontend.
   */
  public function includes() {

    // CONTROLLERS
    include_once(dirname( __FILE__ ) . '/lib/controllers/coupons_controller.php' );

    // HELPERS
    include_once(dirname( __FILE__ ) . '/lib/helpers/coupon_helper.php' );

    // MODELS
    include_once(dirname( __FILE__ ) . '/lib/models/coupon_model.php' );

  }

  public function add_menu_links($menus){
    if(!OsAuthHelper::is_admin_logged_in()) return $menus;
    array_splice($menus, 8, 0, [['id' => 'customers', 'label' => __( 'Coupons', 'latepoint-coupons' ), 'icon' => 'latepoint-icon latepoint-icon-tag', 'link' => OsRouterHelper::build_link(['coupons', 'index'])]]);
    return $menus;
  }

  public function init_hooks(){
    add_action('latepoint_includes', [$this, 'includes']);

    add_action( 'init', array( $this, 'init' ), 0 );

    add_filter('latepoint_installed_addons', [$this, 'register_addon']);
    add_filter('latepoint_side_menu', [$this, 'add_menu_links']);
    add_filter('latepoint_addons_sqls', [$this, 'db_sqls']);

    add_filter('latepoint_filter_payment_total_info', 'OsCouponHelper::get_payment_total_info_with_coupon_html', 10, 2);

    add_filter( 'latepoint_full_amount', 'OsCouponHelper::apply_coupons_on_amount', 15, 3 );
    add_filter( 'latepoint_need_to_show_payment_step', [$this, 'need_to_show_payment_step']);


    add_filter('latepoint_bookings_data_for_csv_export', [$this, 'add_coupon_code_to_bookings_data_for_csv'], 11, 2);
    add_filter('latepoint_booking_row_for_csv_export', [$this, 'add_coupon_code_to_booking_row_for_csv'], 11, 3);

    register_activation_hook(__FILE__, [$this, 'on_activate']);
    register_deactivation_hook(__FILE__, [$this, 'on_deactivate']);


  }



  /**
   * Init LatePoint when WordPress Initialises.
   */
  public function init() {
    // Set up localisation.
    $this->load_plugin_textdomain();
  }

  public function load_plugin_textdomain() {
    load_plugin_textdomain('latepoint-coupons', false, dirname(plugin_basename(__FILE__)) . '/languages');
  }

  public function on_deactivate(){
  }

  public function on_activate(){
    if(class_exists('OsDatabaseHelper')) OsDatabaseHelper::check_db_version_for_addons();
    do_action('latepoint_on_addon_activate', $this->addon_name, $this->version);
  }

  public function register_addon($installed_addons){
    $installed_addons[] = ['name' => $this->addon_name, 'db_version' => $this->db_version, 'version' => $this->version];
    return $installed_addons;
  }

  public function db_sqls($sqls){

    global $wpdb;

    $charset_collate = $wpdb->get_charset_collate();

    $sqls[] = "CREATE TABLE ".LATEPOINT_TABLE_COUPONS." (
      id mediumint(9) NOT NULL AUTO_INCREMENT,
      code varchar(110) NOT NULL,
      name varchar(110),
      discount_type varchar(110),
      discount_value decimal(10,2),
      description text,
      rules text,
      status varchar(20) NOT NULL,
      created_at datetime,
      updated_at datetime,
      UNIQUE KEY code_index (code),
      PRIMARY KEY  (id)
    ) $charset_collate;";
    return $sqls;
  }

  public function need_to_show_payment_step($need){
    $need = true;
    return $need;
  }


  public function add_coupon_code_to_booking_row_for_csv($booking_row, $booking, $params = []){
    $booking_row[] = $booking->coupon_code;
    return $booking_row;
  }


  public function add_coupon_code_to_bookings_data_for_csv($bookings_data, $params = []){
    $bookings_data[0][] = __('Coupon Code', 'latepoint-coupons');
    return $bookings_data;
  }



}

endif;
if ( in_array( 'latepoint/latepoint.php', get_option( 'active_plugins', array() ) )  || array_key_exists('latepoint/latepoint.php', get_site_option('active_sitewide_plugins', array())) ) {
	$LATEPOINT_ADDON_COUPONS = new LatePointAddonCoupons();
}

