<?php
/**
 * Plugin Name: LatePoint Addon - Payments Braintree
 * Plugin URI:  https://latepoint.com/
 * Description: LatePoint addon for payments via Braintree
 * Version:     1.0.3
 * Author:      LatePoint
 * Author URI:  https://latepoint.com/
 * Text Domain: latepoint-payments-braintree
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

// If no LatePoint class exists - exit, because LatePoint plugin is required for this addon

if ( ! class_exists( 'LatePointPaymentsBraintree' ) ) :

/**
 * Main Addon Class.
 *
 */

class LatePointPaymentsBraintree {

  /**
   * Addon version.
   *
   */
  public $version = '1.0.3';
  public $db_version = '1.0.0';
  public $addon_name = 'latepoint-payments-braintree';

  public $processor_code = 'braintree';


  /**
   * LatePoint Constructor.
   */
  public function __construct() {
    $this->define_constants();
    $this->init_hooks();
  }

  /**
   * Define LatePoint Constants.
   */
  public function define_constants() {
  }


  public static function public_stylesheets() {
    return plugin_dir_url( __FILE__ ) . 'public/stylesheets/';
  }

  public static function public_javascripts() {
    return plugin_dir_url( __FILE__ ) . 'public/javascripts/';
  }

  public static function images_url() {
    return plugin_dir_url( __FILE__ ) . 'public/images/';
  }


  /**
   * Define constant if not already set.
   *
   */
  public function define( $name, $value ) {
    if ( ! defined( $name ) ) {
      define( $name, $value );
    }
  }

  /**
   * Include required core files used in admin and on the frontend.
   */
  public function includes() {

    // COMPOSER AUTOLOAD
    require (dirname( __FILE__ ) . '/vendor/autoload.php');

    // CONTROLLERS
    include_once( dirname( __FILE__ ) . '/lib/controllers/payments_braintree_controller.php' );

    // HELPERS
    include_once( dirname( __FILE__ ) . '/lib/helpers/payments_braintree_helper.php' );

    // MODELS

  }

  public function latepoint_init(){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)) OsPaymentsBraintreeHelper::set_api_key();
  }

  public function init_hooks(){
    add_action('latepoint_init', [$this, 'latepoint_init']);
    add_action('latepoint_includes', [$this, 'includes']);
    add_action('latepoint_wp_enqueue_scripts', [$this, 'load_front_scripts_and_styles']);
    add_action('latepoint_admin_enqueue_scripts', [$this, 'load_admin_scripts_and_styles']);
    add_action('latepoint_payment_processor_settings',[$this, 'add_settings_fields'], 10);

    add_filter('latepoint_localized_vars_front', [$this, 'localized_vars_for_front']);
    add_filter('latepoint_localized_vars_admin', [$this, 'localized_vars_for_admin']);

    add_filter('latepoint_payment_processors', [$this, 'register_payment_processor'], 10, 2);
    add_filter('latepoint_all_payment_methods', [$this, 'register_payment_methods']);
    add_filter('latepoint_enabled_payment_methods', [$this, 'register_enabled_payment_methods']);
    add_filter('latepoint_installed_addons', [$this, 'register_addon']);

    add_filter('latepoint_prepare_step_vars_for_view', [$this, 'add_vars_for_payment_step'], 10, 3);
    add_filter('latepoint_prepare_step_booking_object', [$this, 'prepare_booking_object_for_step'], 10, 2);
    add_filter('latepoint_payment_sub_step_for_payment_step', [$this, 'sub_step_for_payment_step']);

    add_filter('latepoint_process_payment_for_booking', [$this, 'process_payment'], 10, 3);
    add_action('latepoint_payment_step_content',[$this, 'output_payment_step_contents'], 10, 2);

    add_filter( 'latepoint_need_to_show_payment_step', [$this, 'need_to_show_payment_step']);

    // addon specific filters

    add_action( 'init', array( $this, 'init' ), 0 );

    register_activation_hook(__FILE__, [$this, 'on_activate']);
    register_deactivation_hook(__FILE__, [$this, 'on_deactivate']);
  }


  public function need_to_show_payment_step($need){
    $need = true;
    return $need;
  }

  public function process_payment($result, $booking, $customer){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      switch($booking->payment_method){
        case 'card':
        case 'paypal':
          if($booking->payment_token){
            // since the payment is already processed on the frontend - we need to retreive payment intent and verify if its paid
            $payment_result = OsPaymentsBraintreeHelper::charge_by_token($booking->payment_token, $booking, $customer);
            if($payment_result['status'] == LATEPOINT_STATUS_SUCCESS){
              $result['status'] = LATEPOINT_STATUS_SUCCESS;
              $result['processor'] = $this->processor_code;
              $result['charge_id'] = $payment_result['charge_id'];
              $result['funds_status'] = $payment_result['funds_status'];
            }else{
              $result['status'] = LATEPOINT_STATUS_ERROR;
              $result['message'] = __('Payment Error', 'latepoint-payments-braintree');
              $booking->add_error('payment_error', $result['message']);
              $booking->add_error('send_to_step', $result['message'], 'payment');
            }
          }else{
            $result['status'] = LATEPOINT_STATUS_ERROR;
            $result['message'] = __('Payment Error 23JDF38', 'latepoint-payments-braintree');
            $booking->add_error('payment_error', $result['message']);
          }
        break;
      }
    }
    return $result;
  }

  public function output_payment_step_contents($booking, $enabled_payment_times){
    if(!OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)) return;
    $deposit_amount = $booking->specs_calculate_deposit_price_to_charge(LATEPOINT_PAYMENT_METHOD_PAYPAL);
    $full_amount = $booking->specs_calculate_full_price_to_charge(LATEPOINT_PAYMENT_METHOD_PAYPAL); ?>
    <?php if(OsPaymentsBraintreeHelper::is_paypal_enabled()){ ?>
      <div class="lp-payment-method-content" data-payment-method="paypal">
        <div class="lp-payment-method-content-i">
          <div class="lp-paypal-btn-trigger-w">
            <div class="latepoint-step-content-text-centered">
              <h4><?php _e('Click the button below to pay using PayPal', 'latepoint'); ?></h4>
              <div><?php _e('You will be able to verify your booking information and confirm it before submitting the payment on the next step.', 'latepoint'); ?></div>
            </div>
            <?php if(OsSettingsHelper::is_env_demo()){ ?>
              <div class="lp-paypal-demo-mode-trigger"><img src="<?php echo LATEPOINT_IMAGES_URL.'payment_paypal.png'; ?>" alt=""><span><?php _e('Demo Mode, click here to continue', 'latepoint'); ?></span></div>
            <?php }else{ ?>
              <div class="lp-paypal-btn-trigger" data-deposit-amount="<?php echo $deposit_amount;?>" data-full-amount="<?php echo $full_amount;?>"></div>
            <?php } ?>
          </div>
        </div>
      </div>
    <?php } ?>
      <div class="lp-payment-method-content" data-payment-method="card" data-init-route="<?php echo OsRouterHelper::build_route_name('payments_braintree', 'calculate_charge_amount'); ?>">
        <div class="lp-payment-method-content-i">
        <div class="lp-payment-method-card-w">
        <?php if(OsSettingsHelper::is_env_demo()) echo '<div class="lp-demo-mode-msg">'.__('Demo Mode, click Next Step to proceed', 'latepoint-payments-braintree').'</div>'; ?>
        <div class="lp-card-i">
          <div class="lp-braintree-card-chip"><div class="chip-i"></div></div>
          <div class="payment-type-credit-card">
            <h4 class="lp-card-header"><?php _e('Card Details', 'latepoint-payments-braintree'); ?></h4>
            <div class="token"></div>
            <div class="os-row">
              <div class="os-col-8">
                <?php if(OsSettingsHelper::is_env_demo()){ ?>
                  <?php echo OsFormHelper::text_field('payment[name_on_card]', __('Name on card', 'latepoint-payments-braintree'), ''); ?>
                <?php }else{ ?>
                  <div class="os-form-group os-form-group-transparent os-form-textfield-group">
                    <label for="payment_name_on_card"><?php _e('Name on card', 'latepoint-payments-braintree'); ?></label>
                    <div id="payment_name_on_card" data-placeholder="<?php _e('Name on card', 'latepoint-payments-braintree'); ?>" class="os-form-control os-framed-field"></div>
                  </div>
                <?php } ?>
              </div>
              <div class="os-col-4">
                <?php if(OsSettingsHelper::is_env_demo()){ ?>
                  <?php echo OsFormHelper::text_field('payment[zip]', __('ZIP', 'latepoint-payments-braintree'), ''); ?>
                <?php }else{ ?>
                  <div class="os-form-group os-form-group-transparent os-form-textfield-group">
                    <label for="payment_zip"><?php _e('ZIP', 'latepoint-payments-braintree'); ?></label>
                    <div id="payment_zip" data-placeholder="<?php _e('ZIP', 'latepoint-payments-braintree'); ?>" class="os-form-control os-framed-field"></div>
                  </div>
                <?php } ?>
              </div>
            </div>
            <div class="os-row">
              <div class="os-col-12">
                <?php if(OsSettingsHelper::is_env_demo()){ ?>
                  <?php echo OsFormHelper::text_field('payment[card_number]', __('Card Number', 'latepoint-payments-braintree'), ''); ?>
                <?php }else{ ?>
                  <div class="os-form-group os-form-group-transparent os-form-textfield-group">
                    <label for="payment_card_number"><?php _e('Card Number', 'latepoint-payments-braintree'); ?></label>
                    <div id="payment_card_number" data-placeholder="<?php _e('Enter Card Number', 'latepoint-payments-braintree'); ?>" class="os-form-control os-framed-field"></div>
                  </div>
                <?php } ?>
              </div>
            </div>
            <div class="os-row">
              <div class="os-col-6">
              </div>
              <div class="os-col-3">
                <?php if(OsSettingsHelper::is_env_demo()){ ?>
                  <?php echo OsFormHelper::text_field('payment[exp_date]', __('Exp.Date', 'latepoint-payments-braintree'), ''); ?>
                <?php }else{ ?>
                  <div class="os-form-group os-form-group-transparent os-form-textfield-group">
                    <label for="payment_card_expiration"><?php _e('Exp.Date', 'latepoint-payments-braintree'); ?></label>
                    <div id="payment_card_expiration" data-placeholder="<?php _e('Exp.Date', 'latepoint-payments-braintree'); ?>" class="os-form-control os-framed-field"></div>
                  </div>
                <?php } ?>
              </div>
              <div class="os-col-3">
                <?php if(OsSettingsHelper::is_env_demo()){ ?>
                  <?php echo OsFormHelper::text_field('payment[cvc]', __('CVC', 'latepoint-payments-braintree'), ''); ?>
                <?php }else{ ?>
                  <div class="os-form-group os-form-group-transparent os-form-textfield-group">
                    <label for="payment_card_cvc"><?php _e('CVC', 'latepoint-payments-braintree'); ?></label>
                    <div id="payment_card_cvc" data-placeholder="<?php _e('CVC', 'latepoint-payments-braintree'); ?>" class="os-form-control os-framed-field"></div>
                  </div>
                <?php } ?>
              </div>
            </div>
          </div>
          </div>
        </div>
        <div class="latepoint-secured-payments-label"><?php _e('All transactions are secure and encrypted. Credit card information is never stored.', 'latepoint-payments-braintree'); ?></div>
        </div>
      </div><?php
  }


  public function sub_step_for_payment_step($sub_step){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $sub_step = 'lp-show-card';
    }
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $sub_step = 'lp-show-paypal';
    }
    return $sub_step;
  }

  public function prepare_booking_object_for_step($booking_object, $step_name){
    if($step_name == 'payment'){
      if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      }
    }
    return $booking_object;
  }

  public function add_vars_for_payment_step($vars, $booking_object, $step_name){
    if($step_name == 'payment'){
      if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
        // add variables for payment step
        $vars['paypal_amount_to_charge'][LATEPOINT_PAYMENT_PORTION_DEPOSIT] = $booking_object->specs_calculate_deposit_price_to_charge(LATEPOINT_PAYMENT_METHOD_PAYPAL);
        $vars['paypal_amount_to_charge'][LATEPOINT_PAYMENT_PORTION_FULL] = $booking_object->specs_calculate_full_price_to_charge(LATEPOINT_PAYMENT_METHOD_PAYPAL);
      }
    }
    return $vars;
  }

  public function register_payment_processor($payment_processors, $enabled_only){
    $payment_processors[$this->processor_code] = ['code' => $this->processor_code, 'name' => __('Braintree', 'latepoint-payments-braintree'), 'image_url' => $this->images_url().'processor-logo.png'];
    return $payment_processors;
  }

  // adds payment method to payment settings
  public function register_payment_methods($payment_methods){
    $payment_methods = array_merge($payment_methods, $this->get_supported_payment_methods());
    return $payment_methods;
  }


  public function register_enabled_payment_methods($enabled_payment_methods){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      $enabled_payment_methods = array_merge($enabled_payment_methods, $this->get_supported_payment_methods());
    }
    return $enabled_payment_methods;
  }

  public function get_supported_payment_methods(){
    $supported_payment_methods = [];
    $supported_payment_methods['card'] = [ 'name' => __('Cards', 'latepoint-payments-braintree'), 
                                           'label' => __('Cards', 'latepoint-payments-braintree'), 
                                           'image_url' => $this->images_url().'payment_cards.png',
                                           'code' => 'card',
                                           'time_type' => 'now' ];
    if(OsPaymentsBraintreeHelper::is_paypal_enabled()){
      $supported_payment_methods['paypal'] = [ 'name' => __('Paypal', 'latepoint-payments-braintree'), 
                                               'label' => __('Paypal', 'latepoint-payments-braintree'), 
                                               'image_url' => $this->images_url().'payment_paypal.png',
                                               'code' => 'paypal',
                                               'time_type' => 'now' ];
    }
    return $supported_payment_methods;
  }

  public function add_settings_fields($processor_code){
    if($processor_code != $this->processor_code) return false; ?>
    <h3 class="os-sub-header"><?php _e('API Keys', 'latepoint-payments-braintree'); ?></h3>
    <div class="os-row">
      <div class="os-col-6">
        <?php echo OsFormHelper::password_field('settings[braintree_merchant_id]', __('Merchant ID', 'latepoint-payments-braintree'), OsSettingsHelper::get_settings_value('braintree_merchant_id')); ?>
      </div>
      <div class="os-col-6">
        <?php echo OsFormHelper::text_field('settings[braintree_tokenization_key]', __('Tokenization Key', 'latepoint-payments-braintree'), OsSettingsHelper::get_settings_value('braintree_tokenization_key')); ?>
      </div>
      <div class="os-col-6">
        <?php echo OsFormHelper::text_field('settings[braintree_publishable_key]', __('Public Key', 'latepoint-payments-braintree'), OsSettingsHelper::get_settings_value('braintree_publishable_key')); ?>
      </div>
      <div class="os-col-6">
        <?php echo OsFormHelper::password_field('settings[braintree_secret_key]', __('Private Key', 'latepoint-payments-braintree'), OsSettingsHelper::get_settings_value('braintree_secret_key')); ?>
      </div>
    </div>
    <h3 class="os-sub-header"><?php _e('PayPal Settings', 'latepoint-payments-braintree'); ?></h3>
    <div class="os-row">
      <div class="os-col-12">
        <?php echo OsFormHelper::toggler_field('settings[braintree_enable_paypal]', __('Enable PayPal Payments via Braintree', 'latepoint'), OsPaymentsBraintreeHelper::is_paypal_enabled()); ?>
      </div>
    </div>
    <h3 class="os-sub-header"><?php _e('Other Settings', 'latepoint-payments-braintree'); ?></h3>
    <?php  
    $selected_braintree_country_code = OsSettingsHelper::get_settings_value('braintree_country_code', 'US');
    $country_currencies = OsPaymentsBraintreeHelper::load_country_currencies_list($selected_braintree_country_code);
    $selected_braintree_currency_iso_code = OsSettingsHelper::get_settings_value('braintree_currency_iso_code', $country_currencies['default_currency']); ?>
    <div class="os-row">
      <div class="os-col-6">
        <?php echo OsFormHelper::select_field('settings[braintree_country_code]', __('Country', 'latepoint-payments-braintree'), OsPaymentsBraintreeHelper::load_countries_list(), $selected_braintree_country_code); ?>
      </div>
      <div class="os-col-6">
        <?php echo OsFormHelper::select_field('settings[braintree_currency_iso_code]', __('Currency Code', 'latepoint-payments-braintree'), $country_currencies['currencies'], $selected_braintree_currency_iso_code); ?>
      </div>
    </div>
  <?php
  }

  /**
   * Init LatePoint when WordPress Initialises.
   */
  public function init() {
    // Set up localisation.
    $this->load_plugin_textdomain();
  }

  public function load_plugin_textdomain() {
    load_plugin_textdomain('latepoint-payments-braintree', false, dirname(plugin_basename(__FILE__)) . '/languages');
  }




  public function on_deactivate(){
  }

  public function on_activate(){
    if(class_exists('OsDatabaseHelper')) OsDatabaseHelper::check_db_version_for_addons();
    do_action('latepoint_on_addon_activate', $this->addon_name, $this->version);
  }

  public function register_addon($installed_addons){
    $installed_addons[] = ['name' => $this->addon_name, 'db_version' => $this->db_version, 'version' => $this->version];
    return $installed_addons;
  }




  public function load_front_scripts_and_styles(){
    if(OsPaymentsHelper::is_payment_processor_enabled($this->processor_code)){
      // Stylesheets
      wp_enqueue_style( 'latepoint-payments-braintree-front', $this->public_stylesheets() . 'latepoint-payments-braintree-front.css', false, $this->version );

      // Javascripts
      // TODO CHECK IF CARD METHOD IS ENABLED
      $dependency = ['jquery', 'latepoint-main-front'];
      wp_enqueue_script( 'braintree-client', 'https://js.braintreegateway.com/web/3.66.0/js/client.min.js', false, null );
      $dependency[] = 'braintree-client';
      if(true){
        // card
        wp_enqueue_script( 'braintree-three-d-secure', 'https://js.braintreegateway.com/web/3.66.0/js/three-d-secure.min.js', false, null );
        wp_enqueue_script( 'braintree-hosted-fields', 'https://js.braintreegateway.com/web/3.66.0/js/hosted-fields.min.js', false, null );
        $dependency[] = 'braintree-three-d-secure';
        $dependency[] = 'braintree-hosted-fields';
      }
      // TODO CHECK IF PAYPAL METHOD IS ENABLED
      if(true){
        // paypal
        wp_enqueue_script( 'braintree-paypal-checkout', 'https://js.braintreegateway.com/web/3.66.0/js/paypal-checkout.min.js', false, null );
        $dependency[] = 'braintree-paypal-checkout';
      }
      wp_enqueue_script( 'latepoint-payments-braintree',  $this->public_javascripts() . 'latepoint-payments-braintree.js', $dependency, $this->version );
    }

  }

  public function load_admin_scripts_and_styles($localized_vars){

    // Stylesheets
  }


  public function localized_vars_for_admin($localized_vars){
    return $localized_vars;
  }

  public function localized_vars_for_front($localized_vars){
    if(true){
      $localized_vars['braintree_key'] = OsPaymentsBraintreeHelper::get_publishable_key();
      $localized_vars['braintree_tokenization_key'] = OsPaymentsBraintreeHelper::get_tokenization_key();
      $localized_vars['is_braintree_active'] = true;
      $localized_vars['braintree_client_token'] = OsPaymentsBraintreeHelper::generate_client_token();
    }
    if(true){
      $localized_vars['is_braintree_paypal_active'] = true;
      $localized_vars['paypal_payment_currency'] = OsPaymentsBraintreeHelper::get_currency_iso_code();
      $localized_vars['braintree_paypal_environment_name'] = OsPaymentsBraintreeHelper::get_environment_name();
      $localized_vars['braintree_paypal_client_auth'] = OsPaymentsBraintreeHelper::generate_client_token();
    }
    return $localized_vars;
  }

}

endif;

if ( in_array( 'latepoint/latepoint.php', get_option( 'active_plugins', array() ) )  || array_key_exists('latepoint/latepoint.php', get_site_option('active_sitewide_plugins', array())) ) {
  $LATEPOINT_ADDON_PAYMENTS_BRAINTREE = new LatePointPaymentsBraintree();
}

