<?php
if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}


if ( ! class_exists( 'OsPaymentsRazorpayController' ) ) :


  class OsPaymentsRazorpayController extends OsController {


    function __construct(){
      parent::__construct();

      $this->action_access['customer'] = array_merge($this->action_access['customer'], ['get_payment_options', 'create_order']);
      $this->views_folder = plugin_dir_path( __FILE__ ) . '../views/payments_razorpay/';
    }

    /* Generates a RazorPay order to be attached to future payment */
    public function create_order(){
      OsStepsHelper::set_booking_object($this->params['booking']);
      OsStepsHelper::set_restrictions($this->params['restrictions']);
      $customer = OsAuthHelper::get_logged_in_customer();
      $this->send_json(array('status' => LATEPOINT_STATUS_SUCCESS, 'message' => $order->id));
    }

    /* Generates payment options for RazorPay payment modal */
    public function get_payment_options(){
      OsStepsHelper::set_booking_object($this->params['booking']);
      OsStepsHelper::set_restrictions($this->params['restrictions']);
      $customer = OsAuthHelper::get_logged_in_customer();

      $amount = OsStepsHelper::$booking_object->specs_calculate_price_to_charge();
      
      if($amount > 0){
        $razorpay_customer_id = $customer->get_meta_by_key('razorpay_customer_id');
        if($razorpay_customer_id){
          $razorpay_customer = OsPaymentsRazorpayHelper::get_customer($razorpay_customer_id);
        }else{
          $razorpay_customer = OsPaymentsRazorpayHelper::create_customer($customer);
          $customer->save_meta_by_key('razorpay_customer_id', $razorpay_customer->id);
        }

        $order = OsPaymentsRazorpayHelper::create_order(OsStepsHelper::$booking_object, $razorpay_customer->id);
        $options = [
              "key" => OsSettingsHelper::get_settings_value('razorpay_publishable_key'),
              "amount" => $amount,
              "currency" => OsSettingsHelper::get_settings_value('razorpay_currency_iso_code', 'INR'),
              "name" => OsSettingsHelper::get_settings_value('razorpay_company_name', 'RazorPay'),
              "description" => "Test Transaction",
              "image" => OsImageHelper::get_image_url_by_id(OsSettingsHelper::get_settings_value('razorpay_logo_image_id', false), 'thumbnail', get_site_icon_url()),
              "prefill" => [
                "email" => $customer->email,
                "contact" => $customer->phone,
                "name" => $customer->full_name
              ],
              "theme" => [
                  "color" => OsSettingsHelper::get_settings_value('razorpay_theme_color', '#4366ff')
              ]
        ];
        if($this->get_return_format() == 'json'){
          $this->send_json(array('status' => LATEPOINT_STATUS_SUCCESS, 'message' => __('Order Created', 'latepoint-payments-razorpay'), 'options' => $options, 'razorpay_order_id' => $order->id, 'amount' => $amount));
        }
      }else{
        // free booking, nothing to pay (probably coupon was applied)
        if($this->get_return_format() == 'json'){
          $this->send_json(array('status' => LATEPOINT_STATUS_SUCCESS, 'message' => __('Nothing to pay', 'latepoint-payments-razorpay'), 'amount' => $amount));
        }
      }
    }
  }


endif;
