class LatepointPaymentsStripeAddon {

	// Init
	constructor(stripeKey){
		this.stripeKey = stripeKey;
		this.stripeElements = null;
		this.stripeCore = null;
		this.stripePaymentMethod = null;
		this.stripePaymentIntentSecret = null;
		this.stripeCardElements = {
			cardNumber: null,
			cardExpiry: null,
			cardCvc: null
		}
		this.ready();
	}

	ready(){
		jQuery(document).ready(() => {
			jQuery('body').on('latepoint:submitBookingForm', '.latepoint-booking-form-element', (e, data) => {
	      if(!latepoint_helper.demo_mode && data.is_final_submit && data.direction == 'next'){
	      	let payment_method = jQuery(e.currentTarget).find('input[name="booking[payment_method]"]').val();
	      	switch(payment_method){
	      		case 'card':
			      	latepoint_add_action(data.callbacks_list, () => {
			      		if(this.stripePaymentIntentSecret && this.stripePaymentMethod && this.stripeCore){
					      	return this.confirmCardPayment(jQuery(e.currentTarget), this.stripePaymentIntentSecret, this.stripePaymentMethod);
			      		}
				      });
	      		break;
	      	}
	      }
			});

			jQuery('body').on('latepoint:nextStepClicked', '.latepoint-booking-form-element', (e, data) => {
	      if(!latepoint_helper.demo_mode && (data.current_step == 'payment')){
	      	let payment_method =  jQuery(e.currentTarget).find('input[name="booking[payment_method]"]').val();
	      	switch(payment_method){
	      		case 'card':
			      	latepoint_add_action(data.callbacks_list, () => {
								return this.createPaymentMethod(jQuery(e.currentTarget), 'card');
			      	});
	      		break;
	      	}
	      }
			});

			jQuery('body').on('latepoint:initPaymentMethod', '.latepoint-booking-form-element', (e, data) => {
				switch(data.payment_method){
      		case 'card':
						latepoint_add_action(data.callbacks_list, () => {
							return this.createPaymentIntent(jQuery(e.currentTarget), data.payment_method);
		      	});
		      break;
				}
			});

			jQuery('body').on('latepoint:initStep:payment', '.latepoint-booking-form-element', (e, data) => {
				this.stripeCore = Stripe(this.stripeKey);
				this.stripeElements = this.stripeCore.elements();
				this.initCreditCardForm(jQuery(e.currentTarget));
			});
		});
	}

	createPaymentMethod($booking_form_element, paymentMethodType){
    let deferred = jQuery.Deferred();
    let options = {
    	type: paymentMethodType
    }
    switch(paymentMethodType){
    	case 'card':
    		options.card = this.stripeCardElements.cardNumber;
    		options.billing_details = {
    			name: $booking_form_element.find('input[name="payment[name_on_card]"]').val()
    		}
    		if(!latepoint_helper.is_stripe_zip_code_removed) options.billing_details.address = { postal_code: $booking_form_element.find('input[name="payment[zip]"]').val() };
    	break;
    }
		this.stripeCore
		  .createPaymentMethod(options)
		  .then((result) => {
			  if (result.error) {
        	deferred.reject({message: result.error.message});
			  } else {
			  	this.stripePaymentMethod = result.paymentMethod;
	      	deferred.resolve();
			  }
		  });
		return deferred;
	}

	createPaymentIntent($booking_form_element, payment_method) {
    let deferred = jQuery.Deferred();
    var data = { 
    	action: 'latepoint_route_call', 
    	route_name: $booking_form_element.find('.lp-payment-method-content[data-payment-method="'+payment_method+'"]').data('init-route'), 
    	params: $booking_form_element.find('.latepoint-form').serialize(), 
    	layout: 'none', 
    	return_format: 'json' 
    }
    jQuery.ajax({
      type : "post",
      dataType : "json",
      url : latepoint_helper.ajaxurl,
      data : data,
      success: (data) => {
        if(data.status === "success"){
        	this.stripePaymentIntentSecret = data.message;
        	latepoint_show_next_btn($booking_form_element);
        	deferred.resolve();
        }else{
        	deferred.reject({message: data.message});
        }
      },
      error: function(request, status, error){
      	deferred.reject({message: error});
      }
    });
	  return deferred;
	}

	confirmCardPayment($booking_form_element, intent_secret, payment_method){
    let deferred = jQuery.Deferred();
		this.stripeCore.confirmCardPayment(
		  intent_secret,
		  {
		    payment_method: payment_method.id
		  }
		).then((result) => {
		  if (result.error) {
      	deferred.reject({message: result.error.message, send_to_step: 'payment'});
		  } else {
		  	$booking_form_element.find('input[name="booking[payment_token]"]').val(result.paymentIntent.id);
      	deferred.resolve();
		  }
		});
	  return deferred;
	}

	// Initiates credit card capture form
	initCreditCardForm($booking_form_element) {


	  let elementStyles = {
	    base: {
	      fontFamily: latepoint_helper.body_font_family,
	      fontSize: '14px',
	      fontWeight: 500,
	      color: '#ffffff',
	      '::placeholder': {
	        color: '#7d89b1'
	      }
	    }
	  }

	  let elementClasses = {
	    focus: 'focused',
	    empty: 'empty',
	    invalid: 'invalid'
	  }

	  this.stripeCardElements.cardNumber = this.stripeElements.create('cardNumber', {
	      style: elementStyles,
	      classes: elementClasses,
	      placeholder: $booking_form_element.find('#payment_card_number').data('placeholder')
	  });
	  this.stripeCardElements.cardNumber.mount($booking_form_element.find('#payment_card_number')[0]);

	  this.stripeCardElements.cardExpiry = this.stripeElements.create('cardExpiry', {
	    style: elementStyles,
	    classes: elementClasses,
	    placeholder: $booking_form_element.find('#payment_card_expiration').data('placeholder')
	  });
	  this.stripeCardElements.cardExpiry.mount($booking_form_element.find('#payment_card_expiration')[0]);

	  this.stripeCardElements.cardCvc = this.stripeElements.create('cardCvc', {
	    style: elementStyles,
	    classes: elementClasses,
	    placeholder: $booking_form_element.find('#payment_card_cvc').data('placeholder')
	  });
	  this.stripeCardElements.cardCvc.mount($booking_form_element.find('#payment_card_cvc')[0]);

	  this.registerCardElements([this.stripeCardElements.cardNumber, this.stripeCardElements.cardExpiry, this.stripeCardElements.cardCvc]);

	}



	// Registers events for mounted elements
	registerCardElements(elementsToRegister) {
	  // Listen for errors from each Element, and show error messages in the UI.
	  elementsToRegister.forEach(function(element) {
	    element.on('change', function(event) {
	      if (event.error) {
	        latepoint_show_message_inside_element(event.error.message);
	      } else {
	        latepoint_hide_message_inside_element();
	      }
	    });
	  });
	}

}


let latepointPaymentsStripeAddon = new LatepointPaymentsStripeAddon(latepoint_helper.stripe_key);