<?php
/**
 * Plugin Name: LatePoint Addon - Timezone Selector
 * Plugin URI:  https://latepoint.com/
 * Description: LatePoint addon for timezone selector
 * Version:     1.0.6
 * Author:      LatePoint
 * Author URI:  https://latepoint.com/
 * Text Domain: latepoint-timezone-selector
 * Domain Path: /languages
 */

if ( ! defined( 'ABSPATH' ) ) {
  exit; // Exit if accessed directly.
}

// If no LatePoint class exists - exit, because LatePoint plugin is required for this addon

if ( ! class_exists( 'LatePointAddonTimezoneSelector' ) ) :

/**
 * Main Addon Class.
 *
 */

class LatePointAddonTimezoneSelector {

  /**
   * Addon version.
   *
   */
  public $version = '1.0.6';
  public $db_version = '1.0.0';
  public $addon_name = 'latepoint-timezone-selector';




  /**
   * LatePoint Constructor.
   */
  public function __construct() {
    $this->define_constants();
    $this->init_hooks();
  }

  /**
   * Define LatePoint Constants.
   */
  public function define_constants() {
    $upload_dir = wp_upload_dir();

    global $wpdb;
  }


  public static function public_stylesheets() {
    return plugin_dir_url( __FILE__ ) . 'public/stylesheets/';
  }

  /**
   * Define constant if not already set.
   *
   */
  public function define( $name, $value ) {
    if ( ! defined( $name ) ) {
      define( $name, $value );
    }
  }

  /**
   * Include required core files used in admin and on the frontend.
   */
  public function includes() {

    // CONTROLLERS
    include_once(dirname( __FILE__ ) . '/lib/controllers/timezone_selector_controller.php' );

    // HELPERS

    // MODELS

  }

  public function init_hooks(){
    add_action('latepoint_includes', [$this, 'includes']);

    add_action( 'init', array( $this, 'init' ), 0 );

    add_action( 'latepoint_settings_steps_after', array( $this, 'add_timezone_settings' ) );
    add_action( 'latepoint_steps_side_panel_after', array( $this, 'output_timezone_selector' ) );
    add_filter( 'latepoint_booking_form_classes', array( $this, 'add_booking_form_class' ) );
    add_filter( 'latepoint_replace_booking_vars', [$this, 'replace_booking_vars_for_timezone'], 10, 2);
    add_action( 'latepoint_available_vars_booking',[$this, 'add_timezone_vars_for_booking'], 15);
    add_action( 'latepoint_available_vars_customer',[$this, 'add_timezone_vars_for_customer'], 15);

    register_activation_hook(__FILE__, [$this, 'on_activate']);
    register_deactivation_hook(__FILE__, [$this, 'on_deactivate']);


  }

  /**
   * Init LatePoint when WordPress Initialises.
   */
  public function init() {
    // Set up localisation.
    $this->load_plugin_textdomain();
  }

  public function add_timezone_vars_for_booking(){
    echo '<li><span class="var-label">'.__('Start Date (in customer timezone):', 'latepoint-timezone-selector').'</span> <span class="var-code os-click-to-copy">{start_date_customer_timezone}</span></li>';
    echo '<li><span class="var-label">'.__('Start Time (in customer timezone):', 'latepoint-timezone-selector').'</span> <span class="var-code os-click-to-copy">{start_time_customer_timezone}</span></li>';
    echo '<li><span class="var-label">'.__('End Time (in customer timezone)', 'latepoint-timezone-selector').'</span> <span class="var-code os-click-to-copy">{end_time_customer_timezone}</span></li>';
  }

  public function add_timezone_vars_for_customer(){
    echo '<li><span class="var-label">'.__('Customer Timezone', 'latepoint-timezone-selector').'</span> <span class="var-code os-click-to-copy">{customer_timezone}</span></li>';
  }

  public static function replace_booking_vars_for_timezone($text, $booking){
    $needles = ['{start_date_customer_timezone}',
                '{start_time_customer_timezone}',
                '{end_time_customer_timezone}',
                '{customer_timezone}'];

    $replacements = [$booking->nice_start_date_for_customer,
                      $booking->nice_start_time_for_customer,
                      $booking->nice_end_time_for_customer,
                      $booking->customer->get_selected_timezone_name()];
    $text = str_replace($needles, $replacements, $text);
    return $text;
  }


  public static function add_booking_form_class($classes){
    if(OsSettingsHelper::is_on('steps_show_timezone_selector')) $classes[] = 'addon-timezone-selector-active';
    return $classes;
  }

  public function output_timezone_selector($active_step_model){
    if(OsSettingsHelper::is_on('steps_show_timezone_selector')){
      echo '<div class="latepoint-timezone-selector-w" data-route-name="'.OsRouterHelper::build_route_name('timezone_selector', 'change_timezone').'">';
        echo OsFormHelper::select_field('latepoint_timezone_selector', __('Times are in:', 'latepoint'), OsTimeHelper::timezones_options_list(OsTimeHelper::get_timezone_name_from_session()), OsTimeHelper::get_timezone_name_from_session());
      echo '</div>';
    }
  }

  public function add_timezone_settings(){
    echo OsFormHelper::checkbox_field('settings[steps_show_timezone_selector]', __('Show Timezone Selector', 'latepoint-timezone-selector'), 'on', OsSettingsHelper::is_on('steps_show_timezone_selector'));
  }

  public function load_plugin_textdomain() {
    load_plugin_textdomain('latepoint-timezone-selector', false, dirname(plugin_basename(__FILE__)) . '/languages');
  }

  public function on_deactivate(){
  }

  public function on_activate(){
    do_action('latepoint_on_addon_activate', $this->addon_name, $this->version);
  }

  public function register_addon($installed_addons){
    $installed_addons[] = ['name' => $this->addon_name, 'db_version' => $this->db_version, 'version' => $this->version];
    return $installed_addons;
  }

  public function db_sqls($sqls){
  }




}

endif;
if ( in_array( 'latepoint/latepoint.php', get_option( 'active_plugins', array() ) )  || array_key_exists('latepoint/latepoint.php', get_site_option('active_sitewide_plugins', array())) ) {
	$LATEPOINT_ADDON_TIMEZONE_SELECTOR = new LatePointAddonTimezoneSelector();
}

